<?php

namespace App\Http\Controllers;

use App\Repositories\UserRepository;
use App\Repositories\ActiviteRepository;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ActiviteController extends Controller
{
    protected $activiteRepository;
    protected $userRepository;

    public function __construct(ActiviteRepository $activiteRepository, UserRepository $userRepository){
        $this->activiteRepository =$activiteRepository;
        $this->userRepository = $userRepository;
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        // dd($user);
        if($user->role=='admin'){
            $activites = $this->activiteRepository->getAllWithuser();
            return view('activite.index',compact('activites','user'));

        }else{
            $activites = $this->activiteRepository->getAllActiviteReportingWithuser(Auth::id());
            $activitep = $this->activiteRepository->getAllActivitePlanifieWithuser(Auth::id());
            return view('activite.index',compact('activites','activitep','user'));
        }

        return view('activite.index',compact('activites','activitep','user'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        $users = $this->userRepository->getAll();
        return view('activite.add',compact('users','user'));
    }
    public function createReporting()
    {
        $users = $this->userRepository->getAll();
        return view('reporting.add',compact('users'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //die(Auth::id());
        if (Auth::check()) {
            $request->merge(['user_id'=>Auth::id(),'etat'=>0]);
            $activites = $this->activiteRepository->store($request->all());
            return redirect('activite');
        }
        else{
            return redirect('login');

        }
        // $request->input('user_id', Auth::id());


    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $activite = $this->activiteRepository->getById($id);
        return view('activite.show',compact('activite'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $users = $this->userRepository->getAll();
        $activite = $this->activiteRepository->getById($id);
        return view('activite.edit',compact('activite','users'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if (Auth::check()) {
            $request->merge(['user_id'=>Auth::id()]);
            $this->activiteRepository->update($id, $request->all());
            return redirect('activite');
        }
        else{
            return redirect('login');

        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $this->activiteRepository->destroy($id);
        return redirect('activite');
    }

    public function getActiviteByUser(){
        $activites = $this->getAllByWithuser(Auth::id());
    }
    public function updateEtat(Request $request){
       // dd($request['activite_id']);
        if (Auth::check()) {
           // $request->merge(['user_id'=>Auth::id()]);

           $activite = $this->activiteRepository->getById($request['activite_id']);

           // $user = Auth::user();
           $activite->etat = $request['etat'];
           $activite->save();
           // $this->activiteRepository->update($id, $request->all());
            return redirect('home');
        }
        else{
            return redirect('login');

        }
    }
    public function getAllActivitePlanification()
    {
        $activitePlanifies = $this->activiteRepository->getAllActivitePlanifier();
        return view('activite.indexp',compact('activitePlanifies'));
    }
    public function getAllActiviteReporting()
    {
        $activiteReportings = $this->activiteRepository->getAllActiviteReporting();
        return view('activite.indexr',compact('activiteReportings'));
    }
}
