<?php
namespace App\Repositories;

use App\Activite;

class ActiviteRepository extends RessourceRepository{

    public function __construct(Activite $activite)
    {
        $this->model = $activite;
    }
    public function getAllWithuser()
    {
        return Activite::with('user')
        ->orderBy('id','desc')
        //->where('type','reporting')
        ->get();
    }
    public function getAllActiviteReportingWithuser($id)
    {
        return Activite::with('user')
        ->orderBy('id','desc')
        ->where([['user_id',$id],['type','reporting']])
        ->get();
    }
    public function getAllActiviteByuser($id)
    {
        return Activite::with('user')
        ->orderBy('id','desc')
        ->where('user_id',$id)
        ->get();
    }
    public function getAllActivitePlanifieWithuser($id)
    {
        return Activite::with('user')
        ->orderBy('id','desc')
        ->where([['user_id',$id],['type','planifie']])
        ->get();
    }
    public function getAllActiviteReporting()
    {
        return Activite::with('user')
        ->orderBy('id','desc')
        ->where('type','reporting')
        ->limit(200)
        ->get()
        ;
    }
    public function getAllActivitePlanifier()
    {
        return Activite::with('user')
        ->orderBy('id','desc')
        ->where('type','planifie')
        ->limit(200)
        ->get();
    }
    public function getActiciteReportingBetWeenToDate($from,$to){
        return Activite::with('user')
        ->where('type','reporting')
        ->whereBetween('created_at',[$from,$to])
        ->orderBy('date','desc')
        ->get();
    }
    public function getActicitePlanifieBetWeenToDate($from,$to){
        return Activite::with('user')
        ->where('type','planifie')
        ->whereBetween('created_at',[$from,$to])
        ->orderBy('date','desc')
        ->get();
    }
    public function getActiciteBetWeenToDate($from,$to){
        return Activite::with('user')
        ->whereBetween('date',[$from,$to])
        ->orderBy('date','desc')
        ->get();
    }
    public function getActiciteBetWeenToDateByUser($from,$to,$id){
        return Activite::with('user')
        ->whereBetween('date',[$from,$to])
        ->where('user_id',$id)
        ->orderBy('date','desc')
        ->get();
    }
    public function getNbActiviteForYear(){
        return Activite::with('user')
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActiviteRealizedForYear(){
        return Activite::with('user')
        ->where('etat',1)
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActiviteNoRealizedForYear(){
        return Activite::with('user')
        ->where('etat',0)
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActiviteByUserForYear($id){
        return Activite::with('user')
        ->where('user_id',$id)
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActivitePlanifie($id){
        return Activite::with('user')
        ->where([['user_id',$id],['type','planifie']])
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActivitePlanifieForALL(){
        return Activite::with('user')
        ->where([['type','planifie']])
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActiviteReporting($id){
        return Activite::with('user')
        ->where([['user_id',$id],['type','reporting']])
        ->whereYear('date',date('Y'))
        ->count();
    }
    public function getNbActiviteReportingForAll(){
        return Activite::with('user')
        ->where('type','reporting')
        ->whereYear('date',date('Y'))
        ->count();
    }

    // Activite par utilisateur
    public function getActiciteReportingBetWeenToDateAndUser($from,$to,$user_id){
        return Activite::with('user')
        ->where([['type','reporting'],['user_id',$user_id]])
        ->whereBetween('updated_at',[$from,$to])
        ->orderBy('date','desc')
        ->get();
    }
    public function getActicitePlanifieBetWeenToDateAndUser($from,$to,$user_id){
        return Activite::with('user')
        ->where([['type','planifie'],['user_id',$user_id]])
        ->whereBetween('updated_at',[$from,$to])
        ->orderBy('date','desc')
        ->get();
    }



}
